@@ -109,6 +109,9 @@ class Website: # pylint: disable=R0902
             website_obj = website
         else:
             website_obj = Website.__set_json_from_str_or_file(website)
+            if os.path.isfile(website) and len(os.path.dirname(website)) > 0:
+                #print(f"changing dir to {os.path.dirname(website)}" )
+                os.chdir(os.path.dirname(website))
 
         Website.__validate_website(website_obj)
 
